import { request } from "../request";
// 响应接口
export interface SelectTotalRes {
	status: boolean;
	msg: string;
	data: Record<string, unknown>;
	code: number;
}

/**
 * 查询所有的班级类
 * @returns
 */
export function selectTotal() {
	return request.get(`/selectTotal`);
}

// 参数接口
export interface SelectConditionParams {
	id?: number | null;
	name?: string | null;
	manageId?: number | null;
	assistantId?: number | null;
	createTime?: string | null;
	modifyTime?: string | null;
	createUid?: number | null;
	disabled?: string | null;
}

// 响应接口
export interface SelectConditionRes {
	status: boolean;
	msg: string;
	data: Record<string, unknown>;
	total: number;
}

/**
 * 根据条件进行查询班级类
 * @param {string} pageNum
 * @param {string} pageSize
 * @param {object} params EasEduClass
 * @param {number} params.id 班级ID
 * @param {string} params.name 班级名称
 * @param {number} params.manageId 班级负责人ID
 * @param {number} params.assistantId 助教老师ID
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function selectCondition(
	pageNum: number | undefined,
	pageSize: number | undefined,
	params: SelectConditionParams
) {
	return request.post(
		`/selectCondition?pageNum=${pageNum}&pageSize=${pageSize}`,
		params
	);
}
// 参数接口
export interface UpdateClassParams {
	id?: number;
	name?: string;
	manageId?: number;
	assistantId?: number;
	createTime?: Record<string, unknown>;
	modifyTime?: Record<string, unknown>;
	createUid?: number;
	disabled?: string;
}

// 响应接口
export interface UpdateClassRes {
	status: boolean;
	msg: string;
	data: Record<string, unknown>;
	code: number;
}

/**
 * 更新班级类
 * @param {object} params EasEduClass
 * @param {number} params.id 班级ID
 * @param {string} params.name 班级名称
 * @param {number} params.manageId 班级负责人ID
 * @param {number} params.assistantId 助教老师ID
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function updateClass(params: UpdateClassParams) {
	return request.put(`/updateClass`, params);
}
// 参数接口
export interface AddClassParams {
	id?: number;
	name?: string;
	manageId?: number;
	assistantId?: number;
	createTime?: Record<string, unknown>;
	modifyTime?: Record<string, unknown>;
	createUid?: number;
	disabled?: string;
}

// 响应接口
export interface AddClassRes {
	status: boolean;
	msg: string;
	data: Record<string, unknown>;
	code: number;
}

/**
 * 增加班级类
 * @param {object} params EasEduClass
 * @param {number} params.id 班级ID
 * @param {string} params.name 班级名称
 * @param {number} params.manageId 班级负责人ID
 * @param {number} params.assistantId 助教老师ID
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function addClass(params: AddClassParams) {
	return request.post(`/addClass`, params);
}
// 响应接口
export interface DeleteClassRes {
	status: boolean;
	msg: string;
	data: Record<string, unknown>;
	code: number;
}

/**
 * 删除班级类
 * @param {string} id
 * @returns
 */
export function deleteClass(id: number) {
	return request.delete(`/deleteClass/${id}`);
}
