import { request } from '../request';
// 参数接口 根据相关条件进行查询课程
export interface SelectByConditionParams {
[x: string]: any;
  id?: number | null;
  name?: string| null;
  description?: string| null;
  categoryId?: number| null;
  createTime?: string| null;
  modifyTime?: string| null;
  createUid?: number| null;
  disabled?: string| null;
}

// 响应接口
export interface SelectByConditionRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  total: number;
}

/**
 * 根据条件进行查询课程
 * @param {string} pageNum
 * @param {string} pageSize
 * @param {object} params EasEduSubjects
 * @param {number} params.id
 * @param {string} params.name 学科名称
 * @param {string} params.description 学科描述
 * @param {string} params.categoryId 学科分类
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function selectByCondition(pageNum: number | undefined, pageSize: number| undefined, params: SelectByConditionParams) {
  return request.post(`/subject/selectByCondition?pageNum=${pageNum}&pageSize=${pageSize}`, params);
}

// 响应接口 查询所有课程
export interface SelectAllRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
}

/**
 * 查询所有课程
 * @returns
 */
export function selectAll() {
  return request.get(`/subject/selectAll`);
}

// 参数接口 添加接口
export interface AddSubjectParams {
  id?: number;
  name?: string;
  description?: string;
  categoryId?: string;
  createTime?: string;
  modifyTime?: string;
  createUid?: number;
  disabled?: string;
}

// 响应接口
export interface AddSubjectRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
}

/**
 * 添加课程
 * @param {object} params EasEduSubjects
 * @param {number} params.id
 * @param {string} params.name 学科名称
 * @param {string} params.description 学科描述
 * @param {string} params.categoryId 学科分类
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function addSubject(params: AddSubjectParams) {
  return request.post(`/subject/addSubject`, params);
}
// 响应接口
export interface DeleteSubjectsRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
}

/**
 * 删除课程
 * @param {string} id
 * @returns
 */
export function deleteSubjects(id: number) {
  return request.delete(`/subject/deleteSubjects/${id}`);
}

// 修改课程
// 参数接口
export interface UpdateSubjectsParams {
  id?: number;
  name?: string;
  description?: string;
  categoryId?: string;
  createTime?: Record<string, unknown>;
  modifyTime?: Record<string, unknown>;
  createUid?: number;
  disabled?: string;
}

// 响应接口
export interface UpdateSubjectsRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
}

/**
 * 修改课程
 * @param {object} params EasEduSubjects
 * @param {number} params.id
 * @param {string} params.name 学科名称
 * @param {string} params.description 学科描述
 * @param {string} params.categoryId 学科分类
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function updateSubjects(params: UpdateSubjectsParams) {
  return request.post(`/subject/updateSubjects`, params);
}

// 响应接口  根据id寻找课程
export interface SelectByIdRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
}

/**
 * id查询课程
 * @param {string} id
  * @returns
 */
export function selectById(id: number) {
  return request.get(`/subject/selectById?id=${id}`);
}

