import { request } from '../request';
// 参数接口
export interface Query_5Params {
  id?: number | null | any;
  checkinDate?: string | null | any;
  scheduleId?: number | null | any;
  month?: number | null | any;
  morning?: string | null | any;
  afternoon?: string | null | any;
  studentName?: string | null | any;
  studentNumber?: string | null | any;
  createUid?: number | null | any;
  createTime?: string | null | any;
  modifyTime?: string	 | null | any;
}

// 响应接口
export interface Query_5Res {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  total: number;
}

/**
 * 查询签到记录
 * @param {string} pageNum
  * @param {string} pageSize
  * @param {object} params EasArcTlsAttendance
 * @param {number} params.id
 * @param {object} params.checkinDate 签到日期
 * @param {number} params.scheduleId 排课ID
 * @param {number} params.month 月份
 * @param {string} params.morning a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.afternoon a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.studentName 学员姓名
 * @param {string} params.studentNumber 学生档案号
 * @param {number} params.createUid 创建用户
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @returns
 */
export function query_5(pageNum: number, pageSize: number, params: Query_5Params) {
  return request.post(`/attendance/query?pageNum=${pageNum}&pageSize=${pageSize}`, params);
}

// 参数接口
export interface Add_5Params {
  id?: number;
  checkinDate?: Record<string, unknown>;
  scheduleId?: number;
  month?: number;
  morning?: string;
  afternoon?: string;
  studentName?: string;
  studentNumber?: string;
  createUid?: number;
  createTime?: Record<string, unknown>;
  modifyTime?: Record<string, unknown>;
}

// 响应接口
export interface Add_5Res {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  code: number;
}

/**
 * 添加签到记录
 * @param {object} params EasArcTlsAttendance
 * @param {number} params.id
 * @param {object} params.checkinDate 签到日期
 * @param {number} params.scheduleId 排课ID
 * @param {number} params.month 月份
 * @param {string} params.morning a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.afternoon a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.studentName 学员姓名
 * @param {string} params.studentNumber 学生档案号
 * @param {number} params.createUid 创建用户
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @returns
 */
export function add_5(params: Add_5Params) {
  return request.post(`/attendance/add`, params);
}

// 参数接口
export interface Update_5Params {
  id?: number;
  checkinDate?: Record<string, unknown>;
  scheduleId?: number;
  month?: number;
  morning?: string;
  afternoon?: string;
  studentName?: string;
  studentNumber?: string;
  createUid?: number;
  createTime?: Record<string, unknown>;
  modifyTime?: Record<string, unknown>;
}

// 响应接口
export interface Update_5Res {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  code: number;
}

/**
 * 更新签到记录
 * @param {object} params EasArcTlsAttendance
 * @param {number} params.id
 * @param {object} params.checkinDate 签到日期
 * @param {number} params.scheduleId 排课ID
 * @param {number} params.month 月份
 * @param {string} params.morning a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.afternoon a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.studentName 学员姓名
 * @param {string} params.studentNumber 学生档案号
 * @param {number} params.createUid 创建用户
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @returns
 */
export function update_5(params: Update_5Params) {
  return request.put(`/attendance/update`, params);
}

// 响应接口
export interface GetStudentListRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  code: number;
}

/**
 * 获取学生列表
 * @param {string} scheduleId
  * @returns
 */
export function getStudentList(scheduleId: number) {
  return request.get(`/attendance/getStudentList?scheduleId=${scheduleId}`);
}

// 参数接口
export interface Delete_5Params {
  id?: number;
  checkinDate?: string;
  scheduleId?: number;
  month?: number;
  morning?: string;
  afternoon?: string;
  studentName?: string;
  studentNumber?: string;
  createUid?: number;
  createTime?: Record<string, unknown>;
  modifyTime?: Record<string, unknown>;
}

// 响应接口
export interface Delete_5Res {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  code: number;
}

/**
 * 删除签到记录
 * @param {object} params EasArcTlsAttendance
 * @param {number} params.id
 * @param {object} params.checkinDate 签到日期
 * @param {number} params.scheduleId 排课ID
 * @param {number} params.month 月份
 * @param {string} params.morning a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.afternoon a  表示正常出勤,   b  表示迟到、早退, c  表示旷课, d  表示请假, e表示无效
 * @param {string} params.studentName 学员姓名
 * @param {string} params.studentNumber 学生档案号
 * @param {number} params.createUid 创建用户
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @returns
 */
export function delete_5(params: Delete_5Params) {
  return request.post(`/attendance/delete`, params);
}
