import { request } from '../request';
// 参数接口
export interface QueryParams {
  id?: number;
  name?: string;
  description?: string;
  isActive?: Record<string, unknown>;
  createTime?: Record<string, unknown>;
  modifyTime?: Record<string, unknown>;
  createUid?: number;
  disabled?: string;
}

// 响应接口
export interface QueryRes {
  status: boolean;
  msg: string;
  data: Record<string, unknown>;
  total: number;
}

/**
 * 查询权限
 * @param {string} pageNum
 * @param {string} pageSize
 * @param {object} params EasSysPermission
 * @param {number} params.id ID
 * @param {string} params.name 权限名称
 * @param {string} params.description 权限描述
 * @param {object} params.isActive 是否激活
 * @param {object} params.createTime 创建时间
 * @param {object} params.modifyTime 修改时间
 * @param {number} params.createUid 创建用户ID
 * @param {string} params.disabled 状态
 * @returns
 */
export function query(pageNum: number | undefined, pageSize: number | undefined, params: QueryParams) {
  return request.post(`/permission/query?pageNum=${pageNum}&pageSize=${pageSize}`, params);
}
